@@ -1,35 +1,76 @@
+# w/o tls
 # linux: https://kitcreator.rkeene.org/kits/840dec4286102c869d85bae3b0dcd32565e7bf12/tclkit
-# osx: https://kitcreator.rkeene.org/kits/6967b89da1f6af7b12cdc82819f3bdb13a661242/tclkit
+# macos: https://kitcreator.rkeene.org/kits/6967b89da1f6af7b12cdc82819f3bdb13a661242/tclkit
+
+# w/ tls
+# linux: http://kitcreator.rkeene.org/kits/c8fe6fba3323b12b924b4a0716609abbaa00822c/tclkit
+# macos: http://kitcreator.rkeene.org/kits/31eaf9ae17e769609700b41d1d3c9abeda27510d/tclkit
+# win: http://kitcreator.rkeene.org/kits/32c6369ff6ef02a685b75854237635d4a3d56611/tclkit.exe
 
 package require http
 package require tar
 package require platform
 
 proc ::build {HOMEDIR BUILDDIR TCLTAG {TOOLCHAIN autoconf-tea}} {
+
+  puts TCLVER=[package req Tcl],[info loaded],$::tcl_patchLevel,[catch {format %d 0777}],[catch {format %d 06440000000}]
+  
   set tarball "tcl.tar.gz"
   set INSTALLDIR [file join $HOMEDIR install]
 
   cd $HOMEDIR
+
+  set URL https://core.tcl-lang.org/tcl/tarball/$tarball?uuid=$TCLTAG
   
-  set fh [open $tarball wb+]
-  try {
-
-    ::http::geturl http://core.tcl.tk/tcl/tarball/$tarball?uuid=$TCLTAG \
-        -binary true \
-        -channel $fh
-
-    seek $fh 0
-    zlib push gunzip $fh
-    ::tar::untar $fh -chan
+  if {![catch {package require tls}]} {
     
-  } on error {e opts} {
-    file delete -force tcl
-    return -options $opts $e
-  } finally {
-    close $fh
-    file delete $tarball
+    http::register https 443 [list ::tls::socket -tls1 1]
+
+    set fh [open $tarball wb+]
+    try {
+      
+      ::http::geturl $URL \
+          -binary true \
+          -channel $fh
+      close $fh
+      # seek $fh 0
+      # zlib push gunzip $fh
+      # ::tar::untar $fh -chan
+
+      puts TCLVER2=[package req Tcl],[info loaded],$::tcl_patchLevel,[catch {format %d 0777}],[catch {format %d 06440000000}]
+
+      exec >@stdout 2>@stderr bash -lc "ls -la"
+      exec >@stdout 2>@stderr bash -lc "7z x -so $tarball | 7z x -aoa -si -ttar"
+      
+    } on error {e opts} {
+      file delete -force tcl
+      return -options $opts $e
+    } finally {
+      catch {close $fh}
+      exec >@stdout 2>@stderr bash -lc "ls -la tcl/"
+      exec >@stdout 2>@stderr bash -lc "pwd"
+      file delete -force $tarball
+    }
+
+
+    
+  } else {
+
+    # fall back to using curl
+    exec >@stdout 2>@stderr bash -lc "curl -L -k -o $tarball $URL"
+
+    # set fh [open $tarball rb]
+    try {
+      # zlib push gunzip $fh
+      # ::tar::untar $fh -chan
+      exec >@stdout 2>@stderr bash -lc "7z x $tarball -so | 7z x -aoa -si -ttar -o tcl"
+      
+    } finally {
+      # close $fh
+      file delete -force $tarball
+    }
   }
-  
+
   # exec tar -xzf tcl.tar.gz
   # https://stackoverflow.com/questions/22333745/how-does-tcl-exec-work-exactly
 
@@ -45,15 +86,18 @@ proc ::build {HOMEDIR BUILDDIR TCLTAG {TOOLCHAIN autoconf-tea}} {
   
   cd $tclDir
 
-  # puts ENV=$::env(PATH)
-  # puts ENV=$::env(HOME)
-  # exec >@stdout 2>@stderr bash -lc "echo \$PATH"
-  # exec >@stdout 2>@stderr bash -lc "cd && pwd"
-  # exec >@stdout 2>@stderr bash -lc "cd && ls -la"
+  puts ENV=$::env(PATH)
+  puts ENV=$::env(HOME)
+  exec >@stdout 2>@stderr bash -lc "echo \$PATH"
+  exec >@stdout 2>@stderr bash -lc "cd && pwd"
+  exec >@stdout 2>@stderr bash -lc "pwd"
+  exec >@stdout 2>@stderr bash -lc "cd && ls -la"
   
   switch -exact -- $TOOLCHAIN {
     autoconf-tea {
-      exec >@stdout 2>@stderr bash -lc "./configure --libdir=$tclDir --enable-64bit"
+      set opts [list --libdir=$tclDir --enable-64bit]
+      
+      exec >@stdout 2>@stderr bash -lc "./configure $opts"
       exec >@stdout 2>@stderr bash -lc "make"
       
       cd $BUILDDIR
