@@ -68,7 +68,7 @@
 #define Tcl_Command_refCount(cmd)      ((Command *)(cmd))->refCount
 #define Tcl_Command_cmdEpoch(cmd)      ((Command *)(cmd))->cmdEpoch
 #define Tcl_Command_flags(cmd)         ((Command *)(cmd))->flags
-/* the following items could be obtained from 
+/* the following items could be obtained from
    Tcl_GetCommandInfoFromToken(cmd, infoPtr) */
 #define Tcl_Command_nsPtr(cmd)         ((Tcl_Namespace*)(((Command *)(cmd))->nsPtr))
 #define Tcl_Command_objProc(cmd)       ((Command *)(cmd))->objProc
@@ -81,6 +81,14 @@
 #define Tcl_Command_deleteProc(cmd)    ((Command *)(cmd))->deleteProc
 #define Tcl_Command_deleteData(cmd)    ((Command *)(cmd))->deleteData
 
+/*
+ * The offsetof() macro is an ANSI C library feature.
+ * Workaround for platforms missing offsetof(), e.g. VC++ 6.0
+ */
+#ifndef offsetof
+# define offsetof(type, field) ((size_t) ((char *) &((type *) 0)->field))
+#endif
+
 /*
  * Var Reform Compatibility support.
  *
@@ -91,7 +99,7 @@
 #define TclIsCompiledLocalArgument(compiledLocalPtr)  ((compiledLocalPtr)->flags & VAR_ARGUMENT)
 #define TclIsCompiledLocalTemporary(compiledLocalPtr) ((compiledLocalPtr)->flags & VAR_TEMPORARY)
 
-#define TclVarHashGetValue(hPtr)	((Var *) ((char *)(hPtr) - TclOffset(VarInHash, entry)))
+#define TclVarHashGetValue(hPtr)	((Var *) ((char *)(hPtr) - offsetof(VarInHash, entry)))
 #define TclVarHashGetKey(varPtr)	(((VarInHash *)(varPtr))->entry.key.objPtr)
 #define TclVarHashTablePtr(varTablePtr)		&(varTablePtr)->table
 #define TclVarValue(type, varPtr, field)	(type *)(varPtr)->value.field
@@ -100,6 +108,40 @@
 # define Tcl_HashSize(tablePtr) ((tablePtr)->numEntries)
 #endif
 
+/*
+ * Starting with [ebe34426255bef25], in Sep 2020, the macro
+ * CMD_IS_DELETED has been replaced by CMD_DYING.
+ * 
+ * See also: 
+ *
+ * https://core.tcl-lang.org/tcl/info/ebe34426255bef25
+ *
+ * https://github.com/tcltk/tcl/commit/23d0bb6cb4e614f464b8e217aa4c7891479e29ff#diff-f9e920c8cca3df7e99caa9e277d717cd736481f4bc54d7df5014a59712ca6397L1731
+ *
+ */
+
+#if TCL_MAJOR_VERSION==8 && TCL_MINOR_VERSION<7 && defined(CMD_IS_DELETED)
+#define TclIsCommandDeleted(cmdPtr)  (((unsigned int)Tcl_Command_flags((cmdPtr)) & CMD_IS_DELETED) != 0u)
+#else
+#define TclIsCommandDeleted(cmdPtr)  (((unsigned int)Tcl_Command_flags((cmdPtr)) & CMD_DYING) != 0u)
+#endif
+
+
+/*
+ * Introduced by a name reform in [a722c92a11], in Oct 2021, the macro
+ * TclFreeIntRep has been replaced by TclFreeInternalRep.
+ * 
+ * See also: 
+ *
+ * https://core.tcl-lang.org/tcl/info/a722c92a1142be4f
+ *
+ * For Tcl 8.7+, we should better switch to using the public interface
+ * to manipulating the internal rep of Tcl_Objs.
+ */
+#if defined(PRE9) && !defined(TclFreeInternalRep)
+# define TclFreeInternalRep(objPtr) TclFreeIntRep((objPtr))
+#endif
+
 
 
 
