@@ -43,8 +43,21 @@
  *
  */
 
-#ifndef _nsf_int_h_
-#define _nsf_int_h_
+#ifndef NSF_INCLUDE_nsf_int_h_
+#define NSF_INCLUDE_nsf_int_h_
+
+#ifndef EXTERN
+# ifdef __cplusplus
+#   define EXTERN extern "C" TCL_STORAGE_CLASS
+# else
+#   define EXTERN extern TCL_STORAGE_CLASS
+# endif
+#endif
+
+#ifndef CONST86
+# define CONST86 const
+#endif
+
 
 /*
  * Well behaved compiler with C99 support should define __STDC_VERSION__
@@ -125,7 +138,7 @@ typedef int bool;
  * ANSI versions.
  *
  * Note: It is sufficient to test for __MINGW32__ to trap all MinGW
- * tool chains, including 64bit versions. See
+ * tool chains, including 64-bit versions. See
  * https://sourceforge.net/p/predef/wiki/Compilers/#mingw-and-mingw-w64
  */
 
@@ -134,6 +147,7 @@ typedef int bool;
 #endif
 
 #include <tclInt.h>
+
 #include "nsf.h"
 
 #include <stdlib.h>
@@ -144,7 +158,7 @@ typedef int bool;
 # include <tclCompile.h>
 #endif
 
-#if __GNUC_PREREQ(2, 95)
+#if NSF__GNUC_PREREQ(2, 95)
 /* Use gcc branch prediction hint to minimize cost of e.g. DTrace
  * ENABLED checks.
  */
@@ -155,31 +169,26 @@ typedef int bool;
 #  define likely(x) (x)
 #endif
 
-#if __GNUC_PREREQ(2, 96)
-# define pure __attribute__((pure))
-#else
-# define pure
-#endif
-
-#if __GNUC_PREREQ(3, 3)
+#if NSF__GNUC_PREREQ(3, 3)
 # define nonnull(ARGS) __attribute__((__nonnull__(ARGS)))
 #else
 # define nonnull(ARGS)
 #endif
 
-#if __GNUC_PREREQ(4, 9)
+#if NSF__GNUC_PREREQ(4, 9)
 # define returns_nonnull __attribute__((returns_nonnull))
 #else
 # define returns_nonnull
 #endif
 
 #define nonnull_assert(assertion) assert((assertion))
+
 /*
- * Tries to use gcc __attribute__ unused and mangles the name, so the
+ * Trie to use gcc __attribute__ unused and mangle the name, so the
  * attribute could not be used, if declared as unused.
  */
 #ifdef UNUSED
-#elif __GNUC_PREREQ(2, 7)
+#elif NSF__GNUC_PREREQ(2, 7)
 # define UNUSED(x) UNUSED_ ## x __attribute__((unused))
 #elif defined(__LCLINT__)
 # define UNUSED(x) /*@unused@*/ (x)
@@ -218,7 +227,7 @@ typedef int bool;
 #endif
 
 /*
- * Makros
+ * Macros
  */
 
 #if defined(PRE86)
@@ -341,9 +350,17 @@ typedef struct NsfMemCounter {
 # include <alloca.h>
 #endif
 
+#ifdef PRE9
+# define NSF_PLAUSIBLE_REFCOUNT(A) ((A)->refCount >= 0)
+# define NSF_PLAUSIBLE_LENGTH(A) ((A)->length >= 0)
+#else
+# define NSF_PLAUSIBLE_REFCOUNT(A) ((A)->refCount < (size_t)-100)
+# define NSF_PLAUSIBLE_LENGTH(A) ((A)->length < (size_t)-100)
+#endif
+
 #if !defined(NDEBUG)
 # define ISOBJ(o) ((o) != NULL && ISOBJ_(o))
-# define ISOBJ_(o) ((o) != (void*)0xdeadbeaf && (((o)->typePtr != NULL) ? ((o)->typePtr->name != NULL) : ((o)->bytes != NULL)) && (((o)->bytes != NULL) ? (o)->length >= -1 : 1) && (o)->refCount >= 0)
+# define ISOBJ_(o) ((o) != (void*)0xdeadbeaf && (((o)->typePtr != NULL) ? ((o)->typePtr->name != NULL) : ((o)->bytes != NULL)) && (((o)->bytes != NULL) ? NSF_PLAUSIBLE_LENGTH(o) : 1) && NSF_PLAUSIBLE_REFCOUNT(o))
 #else
 # define ISOBJ(o)
 #endif
@@ -361,10 +378,10 @@ typedef struct NsfMemCounter {
 
 #ifdef USE_TCL_STUBS
 # define DECR_REF_COUNT(A) \
-  MEM_COUNT_FREE("INCR_REF_COUNT" #A,(A)); assert((A)->refCount > -1);	\
+  MEM_COUNT_FREE("INCR_REF_COUNT" #A,(A)); assert(NSF_PLAUSIBLE_REFCOUNT(A)); \
   Tcl_DecrRefCount(A)
 # define DECR_REF_COUNT2(name,A)					\
-  MEM_COUNT_FREE("INCR_REF_COUNT-" name,(A)); assert((A)->refCount > -1); \
+  MEM_COUNT_FREE("INCR_REF_COUNT-" name,(A)); assert(NSF_PLAUSIBLE_REFCOUNT(A)); \
   Tcl_DecrRefCount(A)
 #else
 # define DECR_REF_COUNT(A) \
@@ -388,8 +405,8 @@ typedef struct NsfMemCounter {
 #ifdef OBJDELETION_TRACE
 # define PRINTOBJ(ctx,object) \
   fprintf(stderr, "  %s %p %s oid=%p teardown=%p destroyCalled=%d\n", \
-	  (ctx),(object),(object)->teardown?ObjStr((object)->cmdName):"(deleted)", \
-	  (object)->id, (object)->teardown,                                 \
+	  (ctx),(void *)(object),(object)->teardown?ObjStr((object)->cmdName):"(deleted)", \
+	  (void *)(object)->id, (void *)(object)->teardown,                                \
 	  ((object)->flags & NSF_DESTROY_CALLED))
 #else
 # define PRINTOBJ(ctx,object)
@@ -718,9 +735,8 @@ typedef enum SystemMethodsIdx {
   NSF_s_set_idx
 } SystemMethodsIdx;
 
-#if !defined(NSF_C)
 EXTERN const char *Nsf_SystemMethodOpts[];
-#else
+#if defined(NSF_C)
 const char *Nsf_SystemMethodOpts[] = {
   "-class.alloc",
   "-class.create",
@@ -785,9 +801,8 @@ typedef enum {
   NSF_STRING_IS, NSF_EVAL, NSF_DISASSEMBLE,
   NSF_RENAME
 } NsfGlobalNames;
-#if !defined(NSF_C)
 EXTERN const char *NsfGlobalStrings[];
-#else
+#if defined(NSF_C)
 const char *NsfGlobalStrings[] = {
   "", "0", "1",
   /* methods called internally */
@@ -837,7 +852,7 @@ EXTERN NsfClassOpt *NsfRequireClassOpt(NsfClass *class)
  * Next Scripting ShadowTclCommands
  */
 typedef struct NsfShadowTclCommandInfo {
-  TclObjCmdProcType proc;
+  Tcl_ObjCmdProc *proc;
   ClientData clientData;
   int nrArgs;
 } NsfShadowTclCommandInfo;
@@ -855,7 +870,7 @@ int NsfShadowTclCommands(Tcl_Interp *interp, NsfShadowOperations load)
   nonnull(1);
 
 Tcl_Obj *NsfMethodObj(const NsfObject *object, int methodIdx)
-  nonnull(1) pure;
+  nonnull(1) NSF_pure;
 
 int NsfReplaceCommandCleanup(Tcl_Interp *interp, Tcl_Obj *nameObj, NsfShadowTclCommandInfo *ti)
   nonnull(1) nonnull(2) nonnull(3);
@@ -1088,12 +1103,12 @@ EXTERN void NsfCleanupObject_(NsfObject *object) nonnull(1);
 #if defined(NSFOBJ_TRACE)
 # define NsfObjectRefCountIncr(object)		\
   ((NsfObject *)(object))->refCount++;		\
-  fprintf(stderr, "RefCountIncr %p count=%d %s\n", (object), ((NsfObject *)(object))->refCount, \
+  fprintf(stderr, "RefCountIncr %p count=%d %s\n", (void *)(object), ((NsfObject *)(object))->refCount, \
 	  ((NsfObject *)object)->cmdName?ObjStr(((NsfObject *)(object))->cmdName):"no name");   \
   MEM_COUNT_ALLOC("NsfObject.refCount", (object))
 # define NsfObjectRefCountDecr(object)					\
   (object)->refCount--;							\
-  fprintf(stderr, "RefCountDecr %p count=%d\n", (object), (object)->refCount); \
+  fprintf(stderr, "RefCountDecr %p count=%d\n", (void *)(object), (object)->refCount); \
   MEM_COUNT_FREE("NsfObject.refCount", (object))
 #else
 # define NsfObjectRefCountIncr(object)          \
@@ -1110,7 +1125,11 @@ EXTERN void NsfCleanupObject_(NsfObject *object) nonnull(1);
  *
  */
 #if defined(NRE)
-# include "stubs8.6/nsfIntDecls.h"
+# if defined(PRE9)
+#  include "stubs8.6/nsfIntDecls.h"
+# else
+#  include "stubs9.0/nsfIntDecls.h"
+# endif
 #else
 # include "stubs8.5/nsfIntDecls.h"
 #endif
@@ -1171,13 +1190,13 @@ void NsfMemCountRelease(void);
  */
 #if defined(TCL_STACK_ALLOC_TRACE)
 # define NsfTclStackFree(interp,ptr,msg) \
-  fprintf(stderr, "---- TclStackFree %p %s\n", ptr, msg);\
+  fprintf(stderr, "---- TclStackFree %p %s\n", (void *)ptr, msg);\
   TclStackFree(interp,ptr)
 
 static char *
-NsfTclStackAlloc(Tcl_Interp *interp, size_t size, char *msg) {
-  char *ptr = TclStackAlloc(interp, size);
-  fprintf(stderr, "---- TclStackAlloc %p %s\n", ptr, msg);
+NsfTclStackAlloc(Tcl_Interp *interp, size_t size, const char *msg) {
+  char *ptr = TclStackAlloc(interp, (int)size);
+  fprintf(stderr, "---- TclStackAlloc %p %s\n", (void *)ptr, msg);
   return ptr;
 }
 #else
@@ -1356,7 +1375,7 @@ EXTERN Nsf_methodDefinition *Nsf_CmdDefinitionGet(Tcl_ObjCmdProc *proc)
 
 
 #ifndef HAVE_STRNSTR
-char *strnstr(const char *buffer, const char *needle, size_t buffer_len) pure;
+char *strnstr(const char *buffer, const char *needle, size_t buffer_len) NSF_pure;
 #endif
 
 /*
@@ -1399,4 +1418,5 @@ char *strnstr(const char *buffer, const char *needle, size_t buffer_len) pure;
 #define NsfCallStackFindLastInvocation(interp, offset, framePtrPtr) \
   NsfCallStackFindCallingContext((interp), (offset), (framePtrPtr), NULL)
 
-#endif /* _nsf_int_h_ */
+EXTERN const Nsf_ObjvTable Nsf_Configureoption[];
+#endif /* NSF_INCLUDE_nsf_int_h_ */
