@@ -41,7 +41,7 @@
 /*
  *----------------------------------------------------------------------
  *
- *  NsfMethodObjType Tcl_Obj type --
+ *      NsfMethodObjType Tcl_Obj type --
  *
  *      The NsfMethodObjType is a Tcl_Obj type carrying the result of
  *      a method lookup. We define two types (NsfInstanceMethodObjType
@@ -71,7 +71,14 @@ Tcl_ObjType NsfObjectMethodObjType = {
 };
 
 /*
- * freeIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * MethodFreeInternalRep --
+ *
+ *      Frees internal representation. Implementation of
+ *      freeIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 MethodFreeInternalRep(
@@ -83,7 +90,8 @@ MethodFreeInternalRep(
   if (mcPtr != NULL) {
 #if defined(METHOD_OBJECT_TRACE)
     fprintf(stderr, "MethodFreeInternalRep %p methodContext %p methodEpoch %d type <%s>\n",
-            objPtr, mcPtr, mcPtr->methodEpoch, (objPtr->typePtr != NULL) ? objPtr->typePtr->name : "none");
+            (void*)objPtr, (void*)mcPtr,
+            mcPtr->methodEpoch, (objPtr->typePtr != NULL) ? objPtr->typePtr->name : "none");
 #endif
     /*
      * ... and free structure
@@ -95,7 +103,14 @@ MethodFreeInternalRep(
 }
 
 /*
- * dupIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * MethodDupInternalRep --
+ *
+ *      Duplicates internal representation. Implementation of
+ *      dupIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 MethodDupInternalRep(
@@ -105,7 +120,7 @@ MethodDupInternalRep(
   register NsfMethodContext *srcMcPtr = srcObjPtr->internalRep.twoPtrValue.ptr1, *dstMcPtr;
 
 #if defined(METHOD_OBJECT_TRACE)
-  fprintf(stderr, "MethodDupInternalRep src %p dst %p\n", srcObjPtr, dstObjPtr);
+  fprintf(stderr, "MethodDupInternalRep src %p dst %p\n", (void *)srcObjPtr, (void *)dstObjPtr);
 #endif
 
   dstMcPtr = NEW(NsfMethodContext);
@@ -119,9 +134,9 @@ MethodDupInternalRep(
 /*
  *----------------------------------------------------------------------
  *
- *  NsfMethodObjSet --
+ * NsfMethodObjSet --
  *
- *      Convert the provided Tcl_Obj into the type of NsfMethodContext.
+ *      Converts the provided Tcl_Obj into the type of NsfMethodContext.
  *
  *----------------------------------------------------------------------
  */
@@ -141,7 +156,8 @@ NsfMethodObjSet(
 #if defined(METHOD_OBJECT_TRACE)
   fprintf(stderr, "... NsfMethodObjSet %p %s context %p methodEpoch %d "
           "cmd %p cl %p %s old obj type <%s> flags %.6x\n",
-          objPtr, ObjStr(objPtr), context, methodEpoch, cmd, cl,
+          (void *)objPtr, ObjStr(objPtr), context, methodEpoch,
+          (void *)cmd, (void *)cl,
           (cl != NULL) ? ClassName(cl) : "obj",
           (objPtr->typePtr != NULL) ? objPtr->typePtr->name : "none", flags);
 #endif
@@ -153,7 +169,7 @@ NsfMethodObjSet(
 #if defined(METHOD_OBJECT_TRACE)
     fprintf(stderr, "... NsfMethodObjSet frees old int rep %s\n", (objPtr->typePtr != NULL) ? objPtr->typePtr->name : "none");
 #endif
-    TclFreeIntRep(objPtr);
+    TclFreeInternalRep(objPtr);
     mcPtr = NEW(NsfMethodContext);
     /*fprintf(stderr, "NsfMethodObjSet allocated NsfMethodContext %p for %s\n", mcPtr, ObjStr(objPtr));*/
     objPtr->internalRep.twoPtrValue.ptr1 = (void *)mcPtr;
@@ -161,13 +177,14 @@ NsfMethodObjSet(
     objPtr->typePtr = objectType;
 #if defined(METHOD_OBJECT_TRACE)
     fprintf(stderr, "alloc %p methodContext %p methodEpoch %d type <%s> %s refCount %d\n",
-            objPtr, mcPtr, methodEpoch, objectType->name, ObjStr(objPtr), objPtr->refCount);
+            (void *)objPtr, (void *)mcPtr,
+            methodEpoch, objectType->name, ObjStr(objPtr), objPtr->refCount);
 #endif
   } else {
     mcPtr = (NsfMethodContext *)objPtr->internalRep.twoPtrValue.ptr1;
 #if defined(METHOD_OBJECT_TRACE)
     fprintf(stderr, "... NsfMethodObjSet %p reuses internal rep, serial (%d/%d) refCount %d\n",
-            objPtr, mcPtr->methodEpoch, methodEpoch, objPtr->refCount);
+            (void *)objPtr, mcPtr->methodEpoch, methodEpoch, objPtr->refCount);
 #endif
   }
 
@@ -188,10 +205,8 @@ NsfMethodObjSet(
 /*
  *----------------------------------------------------------------------
  *
- *  NsfFlagObjType --
- *
- *      The NsfFlagObjType is a Tcl_Obj type carrying the result of a
- *      flag lookup.
+ * The NsfFlagObjType is a Tcl_Obj type carrying the result of a flag
+ * lookup.
  *
  *----------------------------------------------------------------------
  */
@@ -208,7 +223,14 @@ Tcl_ObjType NsfFlagObjType = {
 };
 
 /*
- * freeIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * FlagFreeInternalRep --
+ *
+ *      Frees internal representation. Implementation of
+ *      freeIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 FlagFreeInternalRep(
@@ -238,7 +260,14 @@ FlagFreeInternalRep(
 }
 
 /*
- * dupIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * FlagDupInternalRep --
+ *
+ *      Duplicates internal representation. Implementation of
+ *      dupIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 FlagDupInternalRep(
@@ -248,7 +277,7 @@ FlagDupInternalRep(
   register NsfFlag *srcPtr = (NsfFlag *)srcObjPtr->internalRep.twoPtrValue.ptr1, *dstPtr;
 
 #if defined(METHOD_OBJECT_TRACE)
-  fprintf(stderr, "FlagDupInternalRepx src %p dst %p\n", srcObjPtr, dstObjPtr);
+  fprintf(stderr, "FlagDupInternalRepx src %p dst %p\n", (void *)srcObjPtr,(void *)dstObjPtr);
 #endif
 
   dstPtr = NEW(NsfFlag);
@@ -262,7 +291,7 @@ FlagDupInternalRep(
 /*
  *----------------------------------------------------------------------
  *
- *  NsfFlagObjSet --
+ *      NsfFlagObjSet --
  *
  *      Convert the provided Tcl_Obj into the type of an NSF flag.
  *
@@ -288,7 +317,7 @@ NsfFlagObjSet(
    * structure as internal representation.
    */
   if (objPtr->typePtr != &NsfFlagObjType) {
-    TclFreeIntRep(objPtr);
+    TclFreeInternalRep(objPtr);
     flagPtr = NEW(NsfFlag);
     assert(flagPtr != NULL);
     /*fprintf(stderr, "NsfFlagObjSet allocated NsfFlag %p for %s\n", flagPtr, ObjStr(objPtr));*/
@@ -326,7 +355,7 @@ NsfFlagObjSet(
 /*
  *----------------------------------------------------------------------
  *
- *  Mixinreg Tcl_Obj type --
+ *      Mixinreg Tcl_Obj type --
  *
  *      The mixin registration type is a Tcl_Obj type carrying a
  *      class and a guard object. The string representation might have
@@ -354,7 +383,14 @@ Tcl_ObjType NsfMixinregObjType = {
 };
 
 /*
- * freeIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * MixinregFreeInternalRep --
+ *
+ *      Frees internal representation. Implementation of
+ *      freeIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 MixinregFreeInternalRep(
@@ -383,7 +419,14 @@ MixinregFreeInternalRep(
 }
 
 /*
- * dupIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * MixinregDupInternalRep --
+ *
+ *      Duplicates internal representation. Implementation of
+ *      dupIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 MixinregDupInternalRep(
@@ -396,27 +439,35 @@ MixinregDupInternalRep(
 
 #if defined(METHOD_OBJECT_TRACE)
   fprintf(stderr, "MixinregDupInternalRep src %p dst %p\n",
-          srcObjPtr, dstObjPtr);
+          (void *)srcObjPtr, (void *)dstObjPtr);
 #endif
   dstPtr = NEW(Mixinreg);
   memcpy(dstPtr, srcPtr, sizeof(Mixinreg));
 
   /*
-   * increment refcounts
+   * Increment refcounts.
    */
   NsfObjectRefCountIncr(&(srcPtr->mixin)->object);
-  if (srcPtr->guardObj != NULL) {INCR_REF_COUNT2("mixinRegPtr->guardObj", srcPtr->guardObj);}
+  if (srcPtr->guardObj != NULL) {
+    INCR_REF_COUNT2("mixinRegPtr->guardObj", srcPtr->guardObj);
+  }
 
   /*
-   * update destination obj
+   * Update destination obj.
    */
   dstObjPtr->typePtr = srcObjPtr->typePtr;
   dstObjPtr->internalRep.twoPtrValue.ptr1 = dstPtr;
 }
 
-
 /*
- * setFromAnyProc
+ *----------------------------------------------------------------------
+ *
+ * MixinregSetFromAny --
+ *
+ *      Sets the type and internal representation when converting to
+ *      this object type. Implementation of setFromAnyProc.
+ *
+ *----------------------------------------------------------------------
  */
 static int
 MixinregSetFromAny(
@@ -490,7 +541,7 @@ MixinregSetFromAny(
        * Free the old internal representation and store own structure as internal
        * representation.
        */
-      TclFreeIntRep(objPtr);
+      TclFreeInternalRep(objPtr);
       objPtr->internalRep.twoPtrValue.ptr1 = (void *)mixinRegPtr;
       objPtr->internalRep.twoPtrValue.ptr2 = NULL;
       objPtr->typePtr = &NsfMixinregObjType;
@@ -511,7 +562,7 @@ MixinregSetFromAny(
  *      Tcl result code, arg two and three on success.
  *
  * Side effects:
- *      None
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -536,7 +587,7 @@ NsfMixinregGet(
      * We got a mixin with an included cmd, but both might have been deleted already.
      */
     if ((mixinRegPtr->mixin->object.flags & NSF_DELETED) != 0u
-        || (Tcl_Command_flags(mixinRegPtr->mixin->object.id) & CMD_IS_DELETED) != 0u) {
+        || TclIsCommandDeleted(mixinRegPtr->mixin->object.id)) {
 
       /*
        * The cmd is deleted. Try to refetch it.
@@ -570,7 +621,7 @@ NsfMixinregGet(
  *      non-of these have the chance to point to a stale entry.
  *
  * Results:
- *      Tcl result code
+ *      A standard Tcl result.
  *
  * Side effects:
  *      Freeing internal rep of Tcl_Objs.
@@ -601,7 +652,7 @@ NsfMixinregInvalidate(
 /*
  *----------------------------------------------------------------------
  *
- *  Filterreg Tcl_Obj type --
+ *      Filterreg Tcl_Obj type --
  *
  *      The filter registration type is a Tcl_Obj type carrying the
  *      name of a filter and a guard object. The string representation
@@ -631,9 +682,15 @@ Tcl_ObjType NsfFilterregObjType = {
     FilterregSetFromAny			/* setFromAnyProc */
 };
 
-
 /*
- * freeIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * FilterregFreeInternalRep --
+ *
+ *      Frees internal representation. Implementation of
+ *      freeIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 FilterregFreeInternalRep(
@@ -662,7 +719,14 @@ FilterregFreeInternalRep(
 }
 
 /*
- * dupIntRepProc
+ *----------------------------------------------------------------------
+ *
+ * FilterregDupInternalRep --
+ *
+ *      Duplicates internal representation. Implementation of
+ *      dupIntRepProc.
+ *
+ *----------------------------------------------------------------------
  */
 static void
 FilterregDupInternalRep(
@@ -678,7 +742,7 @@ FilterregDupInternalRep(
   assert(srcPtr != NULL);
 
 #if defined(METHOD_OBJECT_TRACE)
-  fprintf(stderr, "FilterregDupInternalRep src %p dst %p\n", srcObjPtr, dstObjPtr);
+  fprintf(stderr, "FilterregDupInternalRep src %p dst %p\n", (void *)srcObjPtr, (void *)dstObjPtr);
 #endif
 
   dstPtr = NEW(Filterreg);
@@ -698,7 +762,14 @@ FilterregDupInternalRep(
 }
 
 /*
- * setFromAnyProc
+ *----------------------------------------------------------------------
+ *
+ * FilterregSetFromAny --
+ *
+ *      Sets the type and internal representation when converting to
+ *      this object type. Implementation of setFromAnyProc.
+ *
+ *----------------------------------------------------------------------
  */
 static int
 FilterregSetFromAny(
@@ -750,7 +821,7 @@ FilterregSetFromAny(
    * Free the old internal representation and store own structure as internal
    * representation.
    */
-  TclFreeIntRep(objPtr);
+  TclFreeInternalRep(objPtr);
   objPtr->internalRep.twoPtrValue.ptr1 = (void *)filterregPtr;
   objPtr->internalRep.twoPtrValue.ptr2 = NULL;
   objPtr->typePtr = &NsfFilterregObjType;
@@ -769,7 +840,7 @@ FilterregSetFromAny(
  *      Tcl result code, arg two and three on success.
  *
  * Side effects:
- *      None
+ *      None.
  *
  *----------------------------------------------------------------------
  */
