@@ -46,17 +46,15 @@ typedef struct NsfProfileData {
 
 /*
  *----------------------------------------------------------------------
- * NsfProfileObjectLabel, NsfProfileMethodLabel --
+ * NsfProfileObjectLabel --
  *
- *    Produce a string label for an object or method using in profiling.
- *    NsfProfileMethodLabel() is available also when compiled without
- *    NSF_PROFILE.
+ *      Produce a string label for an object as used in profiling.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    Initializes and fills the passed Tcl_DString,
+ *      Initializes and fills the passed Tcl_DString.
  *
  *----------------------------------------------------------------------
  */
@@ -69,11 +67,25 @@ NsfProfileObjectLabel(Tcl_DString *dsPtr, NsfObject *object) {
   nonnull_assert(dsPtr != NULL);
   nonnull_assert(object != NULL);
 
-  Tcl_DStringAppend(dsPtr, ObjectName_(object), -1);
+  Tcl_DStringAppend(dsPtr, ObjectName_(object), TCL_INDEX_NONE);
   Tcl_DStringAppend(dsPtr, " ", 1);
-  Tcl_DStringAppend(dsPtr, ClassName(object->cl), -1);
+  Tcl_DStringAppend(dsPtr, ClassName(object->cl), TCL_INDEX_NONE);
 }
 
+/*
+ *----------------------------------------------------------------------
+ * NsfProfileMethodLabel --
+ *
+ *      Produce a string label for a method as used in profiling.
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      Initializes and fills the passed Tcl_DString.
+ *
+ *----------------------------------------------------------------------
+ */
 static void NsfProfileMethodLabel(Tcl_DString *dsPtr, NsfClass *class, const char *methodName)
   nonnull(1) nonnull(3);
 
@@ -86,7 +98,7 @@ NsfProfileMethodLabel(Tcl_DString *dsPtr, NsfClass *class, const char *methodNam
   Tcl_DStringAppendElement(dsPtr, methodName);
   if (class != NULL) {
     Tcl_DStringAppend(dsPtr, " ", 1);
-    Tcl_DStringAppend(dsPtr, ObjStr(class->object.cmdName), -1);
+    Tcl_DStringAppend(dsPtr, ObjStr(class->object.cmdName), TCL_INDEX_NONE);
   }
 
 }
@@ -96,14 +108,14 @@ NsfProfileMethodLabel(Tcl_DString *dsPtr, NsfClass *class, const char *methodNam
  *----------------------------------------------------------------------
  * NsfProfileDeprecatedCall --
  *
- *    Output a line in case a deprecated function/method is called using
- *    the low-level NsfDeprecatedCmd() function.
+ *      Output a line in case a deprecated function/method is called using
+ *      the low-level NsfDeprecatedCmd() function.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    logging
+ *      Logging.
  *
  *----------------------------------------------------------------------
  */
@@ -128,17 +140,17 @@ NsfProfileDeprecatedCall(Tcl_Interp *interp, NsfObject *UNUSED(object), NsfClass
 
 /*
  *----------------------------------------------------------------------
- * NsfProfileDebugCall, NsfProfileDebugExit --
+ * NsfProfileDebugCall --
  *
- *    Output a line in case a function/method is called/exited having the
- *    debug flag set.  These two functions use the Tcl commands ::nsf::debug::call
- *    and ::nsf::debug::exit for reporting.
+ *      Output a line in case a function/method is called having the
+ *      debug flag set.  This function is used by the Tcl command
+ *      ::nsf::debug::call for reporting.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    logging
+ *      Logging.
  *
  *----------------------------------------------------------------------
  */
@@ -164,7 +176,7 @@ NsfProfileDebugCall(Tcl_Interp *interp, NsfObject *object, NsfClass *class, cons
   NsfProfileMethodLabel(&ds, class, methodName);
   Tcl_DStringAppend(&ds, "}", 1);
 
-  listObj = Tcl_NewListObj(objc, objv);
+  listObj = Tcl_NewListObj((TCL_SIZE_T)objc, objv);
   INCR_REF_COUNT(listObj);
   Nsf_DStringPrintf(&ds, " {%s}", ObjStr(listObj));
   DECR_REF_COUNT(listObj);
@@ -175,6 +187,22 @@ NsfProfileDebugCall(Tcl_Interp *interp, NsfObject *object, NsfClass *class, cons
 
 }
 
+/*
+ *----------------------------------------------------------------------
+ * NsfProfileDebugExit --
+ *
+ *      Output a line in case a function/method is exited having the
+ *      debug flag set.  This function is used by ::nsf::debug::exit
+ *      for reporting.
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      Logging.
+ *
+ *----------------------------------------------------------------------
+ */
 void
 NsfProfileDebugExit(Tcl_Interp *interp, NsfObject *object, NsfClass *class, const char *methodName,
                     long startSec, long startUsec) {
@@ -193,7 +221,7 @@ NsfProfileDebugExit(Tcl_Interp *interp, NsfObject *object, NsfClass *class, cons
   }
   Tcl_DStringAppend(dsPtr, "} {", 3);
   NsfProfileMethodLabel(dsPtr, class, methodName);
-  Tcl_DStringAppend(dsPtr, "} ", 1);
+  Tcl_DStringAppend(dsPtr, "} ", 2);
   Tcl_DStringAppendElement(dsPtr, ObjStr(Tcl_GetObjResult(interp)));
 
   if (startSec != 0 || startUsec != 0) {
@@ -202,7 +230,7 @@ NsfProfileDebugExit(Tcl_Interp *interp, NsfObject *object, NsfClass *class, cons
     Tcl_GetTime(&trt);
     Nsf_DStringPrintf(dsPtr, " %ld ", (trt.sec - startSec) * 1000000 + (trt.usec - startUsec));
   } else {
-    Tcl_DStringAppend(dsPtr, " {}", 4);
+    Tcl_DStringAppend(dsPtr, " {}", 3);
   }
 
   NsfDStringEval(interp, &ds, "debug exit", (NSF_EVAL_DEBUG|NSF_EVAL_SAVE|NSF_EVAL_NOPROFILE));
@@ -217,15 +245,15 @@ NsfProfileDebugExit(Tcl_Interp *interp, NsfObject *object, NsfClass *class, cons
  *----------------------------------------------------------------------
  * ReportLine --
  *
- *    Report a profile line via NsfLog(). Since NsfLog() uses a Tcl function,
- *    ReportLine has to turn off profiling to avoid recursive profile
- *    invocation. It is as well necessary to save the interp result.
+ *      Report a profile line via NsfLog(). Since NsfLog() uses a Tcl function,
+ *      ReportLine has to turn off profiling to avoid recursive profile
+ *      invocation. It is as well necessary to save the interp result.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    logging
+ *      Logging.
  *
  *----------------------------------------------------------------------
  */
@@ -259,14 +287,14 @@ ReportLine(Tcl_Interp *interp, int level, NsfRuntimeState *rst, const char *line
  *----------------------------------------------------------------------
  * NsfProfileFillTable --
  *
- *    Insert or Update a keyed entry with provided microseconds and
- *    update the counts for this entry.
+ *      Insert or Update a keyed entry with provided microseconds and
+ *      update the counts for this entry.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    Updated or created profile data entry
+ *      Updated or created profile data entry.
  *
  *----------------------------------------------------------------------
  */
@@ -299,13 +327,13 @@ NsfProfileFillTable(Tcl_HashTable *table, const char *keyStr, double totalMicroS
  *----------------------------------------------------------------------
  * Nsf_ProfileFilterObjCmd --
  *
- *    Stub command to include C-level commands in profile traces.
+ *      Stub command to include C-level commands in profile traces.
  *
  * Results:
- *    Tcl result code
+ *      A standard Tcl result.
  *
  * Side effects:
- *    Perform tracing
+ *      Perform tracing
  *
  *----------------------------------------------------------------------
  */
@@ -332,10 +360,10 @@ Nsf_ProfileFilterObjCmd(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *co
     }
 
     Tcl_DStringInit(&ds);
-    Tcl_DStringAppend(&ds, fullMethodName, -1);
+    Tcl_DStringAppend(&ds, fullMethodName, TCL_INDEX_NONE);
     for (i = 1; i<=nrArgs; i++) {
       Tcl_DStringAppend(&ds, " ", 1);
-      Tcl_DStringAppend(&ds, ObjStr(objv[i]), -1);
+      Tcl_DStringAppend(&ds, ObjStr(objv[i]), TCL_INDEX_NONE);
     }
     label = ds.string;
   }
@@ -343,7 +371,7 @@ Nsf_ProfileFilterObjCmd(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *co
   NsfProfileTraceCallAppend(interp, label);
 
   Tcl_GetTime(&start);
-  result = Tcl_NRCallObjProc(interp, ti->proc, ti->clientData, objc, objv);
+  result = Tcl_NRCallObjProc(interp, ti->proc, ti->clientData, (TCL_SIZE_T)objc, objv);
   NsfProfileRecordProcData(interp, label, start.sec, start.usec);
 
   if (label != fullMethodName) {
@@ -356,13 +384,13 @@ Nsf_ProfileFilterObjCmd(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *co
  *----------------------------------------------------------------------
  * GetPair --
  *
- *    Split a Tcl_Obj into a nameObj and an integer value, if possible
+ *      Split a Tcl_Obj into a nameObj and an integer value, if possible
  *
  * Results:
- *    Tcl result
+ *      A standard Tcl result.
  *
  * Side effects:
- *    Produce warnings for error cases, when "verbose" is on.
+ *      Produce warnings for error cases, when "verbose" is on.
  *
  *----------------------------------------------------------------------
  */
@@ -407,15 +435,15 @@ GetPair(Tcl_Interp *interp, Tcl_Obj *objPtr, int verbose, Tcl_Obj **nameObjPtr,
  *----------------------------------------------------------------------
  * NsfProfileTrace --
  *
- *    Function to control trace behavior callable via Tcl.
+ *      Function to control trace behavior callable via Tcl.
  *
  * Results:
- *    OK
+ *      OK
  *
  * Side effects:
- *    update RUNTIME_STATE(interp)->doTrace
- *    and    profilePtr->verbose
- *    and    profilePtr->inmemory
+ *      update RUNTIME_STATE(interp)->doTrace
+ *      and    profilePtr->verbose
+ *      and    profilePtr->inmemory
  *
  *----------------------------------------------------------------------
  */
@@ -519,14 +547,14 @@ NsfProfileTrace(Tcl_Interp *interp, int withEnable, int withVerbose, int withDon
  *----------------------------------------------------------------------
  * NsfProfileTraceCallAppend, NsfProfileTraceExitAppend --
  *
- *    Low level function to add entries to the trace Tcl_DString when functions ar
- *    called or exited.
+ *      Low level function to add entries to the trace Tcl_DString when functions ar
+ *      called or exited.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    update profilePtr->depth and profilePtr->traceDs
+ *      update profilePtr->depth and profilePtr->traceDs
  *
  *----------------------------------------------------------------------
  */
@@ -575,20 +603,19 @@ NsfProfileTraceExitAppend(Tcl_Interp *interp, const char *label, double duration
  *----------------------------------------------------------------------
  * NsfProfileTraceCall, NsfProfileTraceExit --
  *
- *    Add entries to the trace Tcl_DString when methods/procs are called or
- *    exited.  This function builds the labels for invocation strings in the
- *    same way as for profiling and calls the lower-level function, which does
- *    the recording.
+ *      Add entries to the trace Tcl_DString when methods/procs are
+ *      called or exited.  This function builds the labels for
+ *      invocation strings in the same way as for profiling and calls
+ *      the lower-level function, which does the recording.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    update profilePtr->depth and profilePtr->traceDs
+ *      update profilePtr->depth and profilePtr->traceDs
  *
  *----------------------------------------------------------------------
  */
-
 void
 NsfProfileTraceCall(Tcl_Interp *interp, NsfObject *object, NsfClass *class, const char *methodName) {
   NsfRuntimeState *rst = RUNTIME_STATE(interp);
@@ -648,17 +675,17 @@ NsfProfileTraceExit(Tcl_Interp *interp, NsfObject *object, NsfClass *class, cons
  *----------------------------------------------------------------------
  * NsfProfileRecordMethodData --
  *
- *    This function is invoked, when a call of a method ends. It
- *    records profiling information based on the provided call stack
- *    content and the caller. In particular, it records the time spent
- *    in an object (identified with an objectKey) and the time spent
- *    in the method (using methodKey).
+ *      This function is invoked, when a call of a method ends. It
+ *      records profiling information based on the provided call stack
+ *      content and the caller. In particular, it records the time spent
+ *      in an object (identified with an objectKey) and the time spent
+ *      in the method (using methodKey).
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    Updated or created profile data entries
+ *      Updated or created profile data entries
  *
  *----------------------------------------------------------------------
  */
@@ -743,14 +770,14 @@ NsfProfileRecordMethodData(Tcl_Interp *interp, NsfCallStackContent *cscPtr) {
  *----------------------------------------------------------------------
  * NsfProfileRecordProcData --
  *
- *    This function is invoked, when a call of a nsf::proc. It records
- *    time spent and count per nsf::proc.
+ *      This function is invoked, when a call of a nsf::proc. It records
+ *      time spent and count per nsf::proc.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    Updated or created profile data entries
+ *      Updated or created profile data entries
  *
  *----------------------------------------------------------------------
  */
@@ -783,13 +810,13 @@ NsfProfileRecordProcData(Tcl_Interp *interp, const char *methodName, long startS
  *----------------------------------------------------------------------
  * NsfProfileClearTable --
  *
- *    Clear all data in a profile table.
+ *      Clear all data in a profile table.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    freed profile information.
+ *      freed profile information.
  *
  *----------------------------------------------------------------------
  */
@@ -816,14 +843,14 @@ NsfProfileClearTable(Tcl_HashTable *table) {
  *----------------------------------------------------------------------
  * NsfProfileClearData --
  *
- *    Flush all data in all profile tables and reset the time
- *    counters.
+ *      Flush all data in all profile tables and reset the time
+ *      counters.
  *
  * Results:
- *    None
+ *      None.
  *
  * Side effects:
- *    freed profile information.
+ *      freed profile information.
  *
  *----------------------------------------------------------------------
  */
@@ -853,14 +880,14 @@ NsfProfileClearData(Tcl_Interp *interp) {
  *----------------------------------------------------------------------
  * NsfProfileGetTable --
  *
- *    Return the profiling information for the specified profile table
- *    in form of a Tcl list.
+ *      Return the profiling information for the specified profile table
+ *      in form of a Tcl list.
  *
  * Results:
- *    Tcl List
+ *      Tcl List
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -881,7 +908,7 @@ NsfProfileGetTable(Tcl_Interp *interp, Tcl_HashTable *table) {
     char           *key = Tcl_GetHashKey(table, hPtr);
     Tcl_Obj        *subList = Tcl_NewListObj(0, NULL);
 
-    Tcl_ListObjAppendElement(interp, subList, Tcl_NewStringObj(key, -1));
+    Tcl_ListObjAppendElement(interp, subList, Tcl_NewStringObj(key, TCL_INDEX_NONE));
     Tcl_ListObjAppendElement(interp, subList, Tcl_NewLongObj(value->microSec));
     Tcl_ListObjAppendElement(interp, subList, Tcl_NewLongObj(value->count));
     Tcl_ListObjAppendElement(interp, list, subList);
@@ -893,16 +920,16 @@ NsfProfileGetTable(Tcl_Interp *interp, Tcl_HashTable *table) {
  *----------------------------------------------------------------------
  * NsfProfileGetData --
  *
- *    Return recorded profiling information. This function returns a
- *    list containing (a) the elapsed time since the last clear (or
- *    init), (b) the cumulative time, (c) the list with the per-object
- *    data and (d) the list with the method invocation data.
+ *      Return recorded profiling information. This function returns a
+ *      list containing (a) the elapsed time since the last clear (or
+ *      init), (b) the cumulative time, (c) the list with the per-object
+ *      data and (d) the list with the method invocation data.
  *
  * Results:
- *    Tcl List
+ *      Tcl List
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -934,15 +961,15 @@ NsfProfileGetData(Tcl_Interp *interp) {
  *----------------------------------------------------------------------
  * NsfProfileInit --
  *
- *    Initialize the profiling information. This is a one-time only
- *    operation and initializes the hash table and the timing
- *    results. The inverse operation is NsfProfileFree()
+ *      Initialize the profiling information. This is a one-time only
+ *      operation and initializes the hash table and the timing
+ *      results. The inverse operation is NsfProfileFree()
  *
  * Results:
- *    None.
+ *      None.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -970,14 +997,14 @@ NsfProfileInit(Tcl_Interp *interp) {
  *----------------------------------------------------------------------
  * NsfProfileFree --
  *
- *    Free all profiling information. This is a one-time only
- *    operation only. The inverse operation is NsfProfileInit().
+ *      Free all profiling information. This is a one-time only
+ *      operation only. The inverse operation is NsfProfileInit().
  *
  * Results:
- *    None.
+ *      None.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
