@@ -49,14 +49,14 @@ static Tcl_ObjCmdProc Nsf_RenameObjCmd;
  *----------------------------------------------------------------------
  * NsfReplaceCommandCleanup --
  *
- *    Undo the effects of NsfReplaceCommand() for the Tcl command
- *    referred by name.
+ *      Undo the effects of NsfReplaceCommand() for the Tcl command
+ *      referred by name.
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -90,14 +90,14 @@ NsfReplaceCommandCleanup(Tcl_Interp *interp, Tcl_Obj *nameObj, NsfShadowTclComma
  *----------------------------------------------------------------------
  * NsfReplaceCommandCheck --
  *
- *    Test, whether shadowing is still in effect, and refresh the
- *    replacement if necessary.
+ *      Test, whether shadowing is still in effect, and refresh the
+ *      replacement if necessary.
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -132,15 +132,15 @@ NsfReplaceCommandCheck(Tcl_Interp *interp, Tcl_Obj *nameObj, Tcl_ObjCmdProc *pro
  *----------------------------------------------------------------------
  * NsfReplaceCommand --
  *
- *    Lookup the objProc of a Tcl command and keep it around for
- *    efficient calling. Replace the objProc optionally with a newly
- *    specified one.
+ *      Lookup the objProc of a Tcl command and keep it around for
+ *      efficient calling. Replace the objProc optionally with a newly
+ *      specified one.
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -181,20 +181,20 @@ NsfReplaceCommand(Tcl_Interp *interp, Tcl_Obj *nameObj,
  *----------------------------------------------------------------------
  * Nsf_InfoBodyObjCmd --
  *
- *    TclObjCmd for shadowing "::tcl::info::body. In case the function
- *    is called with an nsf::proc (which is technically a command, not
- *    a proc), the original command fails ("not a proc"). We catch this
- *    call here and test, whether the body is from an nsf::proc. If
- *    so, we call tcl::info::body with the shadowed body.
+ *      TclObjCmd for shadowing "::tcl::info::body. In case the function
+ *      is called with an nsf::proc (which is technically a command, not
+ *      a proc), the original command fails ("not a proc"). We catch this
+ *      call here and test, whether the body is from an nsf::proc. If
+ *      so, we call tcl::info::body with the shadowed body.
  *
- *    Example:
- *       nsf::proc foo {-a} {puts $a};  info body foo
+ *      Example:
+ *          nsf::proc foo {-a} {puts $a};  info body foo
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -214,9 +214,9 @@ Nsf_InfoBodyObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
   cmd = Tcl_FindCommand(interp, ObjStr(objv[1]), (Tcl_Namespace *)NULL, 0);
   if (cmd != NULL) {
     Tcl_ObjCmdProc *proc =  Tcl_Command_objProc(cmd);
-    ClientData clientData = Tcl_Command_objClientData(cmd);
-    if (proc == NsfProcStub && clientData) {
-      NsfProcClientData *tcd = clientData;
+    ClientData      procClientData = Tcl_Command_objClientData(cmd);
+    if (proc == NsfProcStub && procClientData != NULL) {
+      NsfProcClientData *tcd = procClientData;
       Tcl_Obj *ov[2];
       /*
        * The command is from an nsf::proc
@@ -236,15 +236,15 @@ Nsf_InfoBodyObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
  *----------------------------------------------------------------------
  * Nsf_RenameObjCmd --
  *
- *    TclObjCmd for shadowing "::rename". We check whether the cmd
- *    refers to an NsfObject. If so we have to destroy and/or "move"
- *    it. Otherwise proceed by calling the shadowed function.
+ *      TclObjCmd for shadowing "::rename". We check whether the cmd
+ *      refers to an NsfObject. If so we have to destroy and/or "move"
+ *      it. Otherwise proceed by calling the shadowed function.
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -262,21 +262,20 @@ Nsf_RenameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc, Tc
   cmd = Tcl_FindCommand(interp, ObjStr(objv[1]), (Tcl_Namespace *)NULL, 0);
   if (cmd != NULL) {
     Tcl_ObjCmdProc *proc =  Tcl_Command_objProc(cmd);
-    ClientData clientData = Tcl_Command_objClientData(cmd);
-    NsfObject *object = NsfGetObjectFromCmdPtr(cmd);
-    Tcl_Command parentCmd;
-    char *newName = ObjStr(objv[2]);
-          
+    ClientData      procClientData = Tcl_Command_objClientData(cmd);
+    NsfObject      *object = NsfGetObjectFromCmdPtr(cmd);
+    Tcl_Command     parentCmd;
+    char           *newName = ObjStr(objv[2]);
     
-    if (proc == NsfProcStub && clientData != NULL &&
+    if (proc == NsfProcStub && procClientData != NULL &&
         *newName != '\0') {
       Tcl_DString fqNewName;
       int result;
-      NsfProcClientData *tcd = clientData;
+      NsfProcClientData *tcd = procClientData;
 
       Tcl_DStringInit(&fqNewName);
       Tcl_DStringAppend(&fqNewName, "::nsf::procs::", 14);
-      Tcl_DStringAppend(&fqNewName, newName, -1);
+      Tcl_DStringAppend(&fqNewName, newName, TCL_INDEX_NONE);
       
       /* fprintf(stderr, "oldName %s newName %s\n", ObjStr(tcd->procName), Tcl_DStringValue(&fqNewName));*/
       result = TclRenameCommand(interp, ObjStr(tcd->procName), Tcl_DStringValue(&fqNewName));
@@ -319,16 +318,16 @@ Nsf_RenameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc, Tc
  *----------------------------------------------------------------------
  * Nsf_InfoFrameObjCmd --
  *
- *    TclObjCmd for shadowing "::tcl::info::frame". First we call the
- *    shadowed method. If it returns OK we check whether the frame is
- *    an NSF frame. If so, we remove from the result the misleading
+ *      TclObjCmd for shadowing "::tcl::info::frame". First we call the
+ *      shadowed method. If it returns OK we check whether the frame is
+ *      an NSF frame. If so, we remove from the result the misleading
  *    "proc" and add "method", "class", "object" and "frametype".
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -396,7 +395,7 @@ Nsf_InfoFrameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
       Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("method", 6));
       Tcl_ListObjAppendElement(interp, listObj,
                                (cscPtr->cmdPtr != NULL)
-                               ? Tcl_NewStringObj(Tcl_GetCommandName(interp, cscPtr->cmdPtr), -1)
+                               ? Tcl_NewStringObj(Tcl_GetCommandName(interp, cscPtr->cmdPtr), TCL_INDEX_NONE)
 			       : NsfGlobalObjs[NSF_EMPTY]);
       Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("frametype", 9));
       if (cscPtr->frameType == NSF_CSC_TYPE_PLAIN) {
@@ -410,7 +409,7 @@ Nsf_InfoFrameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
       } else {
         frameType = "unknown";
       }
-      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(frameType, -1));
+      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(frameType, TCL_INDEX_NONE));
       Tcl_SetObjResult(interp, listObj);
     } else if (frameFlags & (FRAME_IS_NSF_OBJECT)) {
       NsfObject *object = (NsfObject *)Tcl_CallFrame_clientData(varFramePtr);
@@ -432,18 +431,19 @@ Nsf_InfoFrameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
  *----------------------------------------------------------------------
  * NsfShadowTclCommands --
  *
- *    Load/refresh/unload shadowed Tcl commands. Essentially, the
- *    shadowing function serve two things:
- *    (a) lookup some Tcl ObjProcs, which are not available via global
- *        symbols and make these available via NsfCallCommand().
- *    (b) some Tcl commands are actually shadowed; we perform some
- *        pre- and/or postprocessing on these calls.
+ *      Load/refresh/unload shadowed Tcl commands. Essentially, the
+ *      shadowing function serve two things:
+ *
+ *      (a) lookup some Tcl ObjProcs, which are not available via global
+ *          symbols and make these available via NsfCallCommand().
+ *      (b) some Tcl commands are actually shadowed; we perform some
+ *          pre- and/or postprocessing on these calls.
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
@@ -502,20 +502,21 @@ NsfShadowTclCommands(Tcl_Interp *interp, NsfShadowOperations load) {
  *----------------------------------------------------------------------
  * NsfCallCommand --
  *
- *    Calls Tcl Commands as direct as possible. The commands have to be looked
- *    up previously via NsfShadowTclCommands(). The element objv[0] is
- *    replaced with the predefined command name.
+ *      Calls a Tcl Command as direct as possible. The commands have to be
+ *      looked up previously via NsfShadowTclCommands(). The element objv[0]
+ *      is replaced with the predefined command name.
  *
  * Results:
- *    Tcl return code.
+ *      A standard Tcl result.
  *
  * Side effects:
- *    None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
-int NsfCallCommand(Tcl_Interp *interp, NsfGlobalNames name,
-	    int objc, Tcl_Obj *const objv[]) {
+int
+NsfCallCommand(Tcl_Interp *interp, NsfGlobalNames name,
+               int objc, Tcl_Obj *const objv[]) {
   int result;
   NsfShadowTclCommandInfo *ti = &RUNTIME_STATE(interp)->tclCommands[name-NSF_EXPR];
   ALLOC_ON_STACK(Tcl_Obj*, objc, ov);
@@ -531,7 +532,7 @@ int NsfCallCommand(Tcl_Interp *interp, NsfGlobalNames name,
   if (objc > 1) {
     memcpy(ov+1, objv+1, sizeof(Tcl_Obj *) * ((size_t)objc - 1u));
   }
-  result = Tcl_NRCallObjProc(interp, ti->proc, ti->clientData, objc, objv);
+  result = Tcl_NRCallObjProc(interp, ti->proc, ti->clientData, (TCL_SIZE_T)objc, objv);
   FREE_ON_STACK(Tcl_Obj *, ov);
   return result;
 }
