@@ -1,5 +1,5 @@
 #
-# Zip file generator - Create a Zip-file from a list of input file names
+# Zip file generator - Create a Zip-file from a list of input filenames
 #
 # This implementation is based on the zip file builder of Artur
 # Trzewik (https://wiki.tcl-lang.org/15158), but was simplified, refactored,
@@ -19,7 +19,7 @@ if {[info commands ::zlib] eq ""} {
   package require Trf
 }
 
-package provide nx::zip 1.2
+package provide nx::zip 1.3
 
 namespace eval ::nx::zip {
 
@@ -34,11 +34,14 @@ namespace eval ::nx::zip {
     #    - ns_returnZipFile  (return a zip file via AOLserver ns_return)
     #
     #    - writeToStream     (for already opened and configured
-    #                        output streams
+    #                        output streams)
     #
 
+    :property name ;# so far not used internally, but useful for
+                    # applications to pass the name around
+
     #
-    # Add a file from the file system to the zip archive
+    # Add a file from the filesystem to the zip archive
     #
     :public method addFile {inputFileName outputFileName:optional} {
       # inputFileName - source file to archive
@@ -64,7 +67,8 @@ namespace eval ::nx::zip {
     #
     :public method writeToZipFile {zipFileName} {
       set fout [open $zipFileName w]
-      fconfigure $fout -translation binary -encoding binary
+      fconfigure $fout -translation binary
+      set :writer [list puts -nonewline $fout]
       :writeToStream $fout
       close $fout
     }
@@ -73,13 +77,41 @@ namespace eval ::nx::zip {
     # return the added files via aolserver/NaviServer to the client
     #
     :public method ns_returnZipFile {zipFileName} {
-      ns_write "HTTP/1.0 200 OK\r\nContent-type: application/zip\r\n"
-      ns_write "Content-Disposition: attachment;filename=\"$zipFileName\"\r\n"
-      ns_write "\r\n"
-      set channel [ns_conn channel]
-      fconfigure $channel -translation binary
-      :writeToStream $channel
-      # AOLserver/NaviServer closes the channel automatically
+      append header \
+          "HTTP/1.0 200 OK\r\nContent-type: application/zip\r\n" \
+          "Content-Disposition: attachment;filename=\"$zipFileName\"\r\n" \
+          "\r\n"
+      #
+      # Check, if we have "ns_connchan status". If so, use ns_connchan
+      # to write to the client. This has the advantage that we can use
+      # the buffered "connchan write" method capable of handling
+      # partial writes also for HTTPS.
+      #
+      if {[info commands ::ns_connchan] ne ""
+          && [info commands ::acs::cmd_has_subcommand] ne ""
+          && [::acs::cmd_has_subcommand ns_connchan status]} {
+        set channel [ns_connchan detach]
+        set :writer [list ns_connchan write -buffered $channel]
+        ns_connchan write -buffered $channel $header
+        :writeToStream $channel
+        while {1} {
+          set status [ns_connchan status $channel]
+          if {[dict get $status sendbuffer] > 0} {
+            ns_connchan write -buffered $channel ""
+            ns_sleep 1ms
+          } else {
+            break
+          }
+        }
+        ns_connchan close $channel
+      } else {
+        ns_write $header
+        set channel [ns_conn channel]
+        fconfigure $channel -translation binary
+        set :writer [list puts -nonewline $channel]
+        :writeToStream $channel
+        # AOLserver closes the channel automatically
+      }
     }
 
     #
@@ -89,7 +121,7 @@ namespace eval ::nx::zip {
       set :outputStream $outputStream
 
       #
-      # Write all files to the outout stream
+      # Write all files to the output stream
       #
       set descriptionList [list]
       foreach {type in fnOut} ${:files} {
@@ -108,7 +140,7 @@ namespace eval ::nx::zip {
 
         # For every file, it contains again part of the information of
         # the local file headers, but with some additional information
-        # such as a the "version made by", comment, ...
+        # such as the "version made by", comment, ...
 
         set comment ""
         set platform 0 ;# dos/windows
@@ -136,7 +168,7 @@ namespace eval ::nx::zip {
 
         # relative offset of local header
         :writeLong $(offset)
-        # file name
+        # filename
         :writeString $(fileNameInternal)
 
         :writeExtraFieldUPATH $(fileName) $(fileNameInternal)
@@ -243,7 +275,7 @@ namespace eval ::nx::zip {
 
       :writeFileHeaderBlock [array get ""]
 
-      # file name
+      # filename
       :writeString $(fileNameInternal)
 
       :writeExtraFieldUPATH $(fileName) $(fileNameInternal)
@@ -276,7 +308,7 @@ namespace eval ::nx::zip {
       :writeLong $(csize)
       :writeLong $(size)
 
-      # file name length
+      # filename length
       :writeShort [string length $(fileNameInternal)]
 
       # extra field length
@@ -284,7 +316,7 @@ namespace eval ::nx::zip {
     }
 
     #
-    # Convert the provided time stamp to DOS time.
+    # Convert the provided timestamp to DOS time.
     #
     :method toDosTime {time} {
       foreach {year month day hour minute second} \
@@ -321,7 +353,7 @@ namespace eval ::nx::zip {
     # Write the provided integer in binary form as a long value (32 bit)
     #
     :method writeLong {long:integer} {
-      puts -nonewline ${:outputStream} [binary format i $long]
+      {*}${:writer} [binary format i $long]
       incr :written 4
     }
 
@@ -329,7 +361,7 @@ namespace eval ::nx::zip {
     # Write the provided integer in binary form as a short value (16 bit)
     #
     :method writeShort {short:integer} {
-      puts -nonewline ${:outputStream} [binary format s $short]
+      {*}${:writer} [binary format s $short]
       incr :written 2
     }
 
@@ -337,7 +369,7 @@ namespace eval ::nx::zip {
     # Write the provided integer in binary form as a single byte (8 bit)
     #
     :method writeByte {byte:integer} {
-      puts -nonewline ${:outputStream} [binary format c $byte]
+      {*}${:writer} [binary format c $byte]
       incr :written 1
     }
 
@@ -346,11 +378,11 @@ namespace eval ::nx::zip {
     # byte counter.
     #
     :method writeString {string} {
-      puts -nonewline ${:outputStream} $string
+      {*}${:writer} $string
       incr :written [string length $string]
     }
     :method writeStringBytes {string} {
-      puts -nonewline ${:outputStream} $string
+      {*}${:writer} $string
       incr :written [string bytelength $string]
     }
 
