@@ -11,7 +11,7 @@
  *
  * -gustaf neumann    March 27, 2011
  *
- * Copyright (C) 2011-2018 Gustaf Neumann
+ * Copyright (C) 2011-2021 Gustaf Neumann
  */
 #include <stdlib.h>
 #include <stdio.h>
@@ -25,6 +25,11 @@
 
 #define USE_CLIENT_POOL 1
 
+/*
+ * Size of handle as used by Nsf_PointerAdd()
+ */
+#define POINTER_HANDLE_SIZE 80u
+
 /*
  * Define the counters to generate nice symbols for pointer converter
  */
@@ -85,7 +90,7 @@ NsfMongoGlobalStrings[] = {
 static Tcl_Obj **NsfMongoGlobalObjs = NULL;
 
 static Tcl_Obj *BsonToList(Tcl_Interp *interp, const bson_t *data , int depth);
-static bson_type_t BsonTagToType(Tcl_Interp *interp, const char *tag);
+static bson_type_t BsonTagToType(Tcl_Interp *interp, Tcl_Obj *tagObj);
 
 extern Tcl_PackageInitProc Nsfmongo_SafeInit;
 extern Tcl_PackageInitProc Nsfmongo_Init;
@@ -227,8 +232,8 @@ BsonToList(Tcl_Interp *interp, const bson_t *data , int depth)
       tag = NSF_BSON_REGEX;
       regex = bson_iter_regex( &i, &options );
       elemObj = Tcl_NewListObj(0, NULL);
-      Tcl_ListObjAppendElement(interp, elemObj, Tcl_NewStringObj(regex, -1));
-      Tcl_ListObjAppendElement(interp, elemObj, Tcl_NewStringObj(options, -1));
+      Tcl_ListObjAppendElement(interp, elemObj, Tcl_NewStringObj(regex, TCL_INDEX_NONE));
+      Tcl_ListObjAppendElement(interp, elemObj, Tcl_NewStringObj(options, TCL_INDEX_NONE));
       break;
     }
     case BSON_TYPE_UTF8: {
@@ -245,7 +250,7 @@ BsonToList(Tcl_Interp *interp, const bson_t *data , int depth)
     case BSON_TYPE_OID: {
       tag = NSF_BSON_OID;
       bson_oid_to_string(bson_iter_oid(&i), oidhex);
-      elemObj = Tcl_NewStringObj(oidhex, -1);
+      elemObj = Tcl_NewStringObj(oidhex, TCL_INDEX_NONE);
       break;
     }
     case BSON_TYPE_TIMESTAMP: {
@@ -287,7 +292,7 @@ BsonToList(Tcl_Interp *interp, const bson_t *data , int depth)
       tag = NSF_BSON_DECIMAL128;
       bson_iter_decimal128( &i, &decimal128);
       bson_decimal128_to_string(&decimal128, string);
-      elemObj = Tcl_NewStringObj(string, -1);
+      elemObj = Tcl_NewStringObj(string, TCL_INDEX_NONE);
 
       break;
     }
@@ -300,19 +305,19 @@ BsonToList(Tcl_Interp *interp, const bson_t *data , int depth)
       elemObj = Tcl_NewByteArrayObj(bytes, (int)length);
       break;
     }
-    case BSON_TYPE_CODE:       /* fall through */
-    case BSON_TYPE_CODEWSCOPE: /* fall through */
-    case BSON_TYPE_DBPOINTER:  /* fall through */
-    case BSON_TYPE_EOD:        /* fall through */
-    case BSON_TYPE_SYMBOL:     /* fall through */
-    case BSON_TYPE_UNDEFINED:  /* fall through */
+    case BSON_TYPE_CODE:       NSF_FALL_THROUGH; /* fall through */
+    case BSON_TYPE_CODEWSCOPE: NSF_FALL_THROUGH; /* fall through */
+    case BSON_TYPE_DBPOINTER:  NSF_FALL_THROUGH; /* fall through */
+    case BSON_TYPE_EOD:        NSF_FALL_THROUGH; /* fall through */
+    case BSON_TYPE_SYMBOL:     NSF_FALL_THROUGH; /* fall through */
+    case BSON_TYPE_UNDEFINED:  NSF_FALL_THROUGH; /* fall through */
     default:
       tag = NSF_BSON_UNKNOWN;
       elemObj = Tcl_NewStringObj("", 0);
       NsfLog(interp, NSF_LOG_WARN, "BsonToList: unknown type %d", t);
     }
 
-    Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj(key, -1));
+    Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj(key, TCL_INDEX_NONE));
     Tcl_ListObjAppendElement(interp, resultObj, NsfMongoGlobalObjs[tag]);
     Tcl_ListObjAppendElement(interp, resultObj, elemObj);
   }
@@ -339,9 +344,10 @@ BsonToList(Tcl_Interp *interp, const bson_t *data , int depth)
  *----------------------------------------------------------------------
  */
 bson_type_t
-BsonTagToType(Tcl_Interp *interp, const char *tag)
+BsonTagToType(Tcl_Interp *interp, Tcl_Obj *tagObj)
 {
-  char firstChar = *tag;
+  const char *tag = ObjStr(tagObj);
+  char        firstChar = *tag;
 
   switch (firstChar) {
   case 'a': /* array */   return BSON_TYPE_ARRAY;
@@ -381,7 +387,7 @@ BsonTagToType(Tcl_Interp *interp, const char *tag)
  *      append a tagged element to a bson buffer.
  *
  * Results:
- *      Tcl result code.
+ *      A standard Tcl result.
  *
  * Side effects:
  *      Value appended to bson buffer.
@@ -389,19 +395,21 @@ BsonTagToType(Tcl_Interp *interp, const char *tag)
  *----------------------------------------------------------------------
  */
 static int
-BsonAppend(Tcl_Interp *interp, bson_t *bbPtr, const char *name, const char *tag, Tcl_Obj *value)
+BsonAppend(Tcl_Interp *interp, bson_t *bbPtr, Tcl_Obj *nameObj, Tcl_Obj *tagObj, Tcl_Obj *value)
 {
   int         result = TCL_OK;
-  bson_type_t t = BsonTagToType(interp, tag);
-  int         keyLength = (int)strlen(name);
+  bson_type_t t = BsonTagToType(interp, tagObj);
+  int         keyLength;
+  const char *name = Tcl_GetStringFromObj(nameObj, &keyLength);
 
   /*fprintf(stderr, "BsonAppend: add name %s tag %s value '%s'\n", name, tag, ObjStr(value));*/
 
   switch ( t ){
   case BSON_TYPE_UTF8: {
-    const char* string = ObjStr(value);
+    int         stringLength;
+    const char* string = Tcl_GetStringFromObj(value, &stringLength);
 
-    bson_append_utf8(bbPtr, name, keyLength, string, (int)strlen(string));
+    bson_append_utf8(bbPtr, name, keyLength, string, stringLength);
     break;
   }
   case BSON_TYPE_INT32: {
@@ -500,7 +508,8 @@ BsonAppend(Tcl_Interp *interp, bson_t *bbPtr, const char *name, const char *tag,
 
     result = Tcl_ListObjGetElements(interp, value, &objc, &objv);
     if (result != TCL_OK || ((objc % 3) != 0)) {
-      return NsfPrintError(interp, "invalid %s value contain multiple of 3 elements %s", tag, ObjStr(value));
+      return NsfPrintError(interp, "invalid %s value contain multiple of 3 elements %s",
+                           ObjStr(tagObj), ObjStr(value));
     }
 
     if (t == BSON_TYPE_DOCUMENT) {
@@ -511,7 +520,7 @@ BsonAppend(Tcl_Interp *interp, bson_t *bbPtr, const char *name, const char *tag,
     for (i = 0; i< objc; i += 3) {
       /*fprintf(stderr, "value %s, i %d, [0]: %s, [1]: %s, [2]: %s\n", ObjStr(value), i,
         ObjStr(objv[i]),  ObjStr(objv[i+1]), ObjStr(objv[i+2]));*/
-      result = BsonAppend(interp, childPtr, ObjStr(objv[i]),  ObjStr(objv[i+1]), objv[i+2]);
+      result = BsonAppend(interp, childPtr, objv[i], objv[i+1], objv[i+2]);
       if (result != TCL_OK) break;
     }
 
@@ -540,7 +549,7 @@ BsonAppend(Tcl_Interp *interp, bson_t *bbPtr, const char *name, const char *tag,
   case BSON_TYPE_CODE:
   case BSON_TYPE_SYMBOL:
   case BSON_TYPE_CODEWSCOPE:
-    return NsfPrintError(interp, "tag %s not handled yet", tag);
+    return NsfPrintError(interp, "tag %s not handled yet", ObjStr(tagObj));
     break;
 
   case BSON_TYPE_UNDEFINED:
@@ -560,7 +569,7 @@ BsonAppend(Tcl_Interp *interp, bson_t *bbPtr, const char *name, const char *tag,
  *      Append all elements of objv to an uninitialized bson buffer.
  *
  * Results:
- *      Tcl result code.
+ *      A standard Tcl result.
  *
  * Side effects:
  *      Value appended to bson buffer.
@@ -574,12 +583,9 @@ BsonAppendObjv(Tcl_Interp *interp, bson_t *bPtr, int objc, Tcl_Obj **objv)
 
   bson_init(bPtr);
   for (i = 0; i < objc; i += 3) {
-    char    *name = ObjStr(objv[i]);
-    char    *tag = ObjStr(objv[i+1]);
-    Tcl_Obj *value = objv[i+2];
-
-    /*fprintf(stderr, "adding pair '%s' (%s) '%s'\n", name, tag, ObjStr(value));*/
-    result = BsonAppend(interp, bPtr, name, tag, value);
+    /*fprintf(stderr, "adding pair '%s' (%s) '%s'\n",
+      ObjStr(objv[i]), ObjStr(objv[i+1]), ObjStr(objv[i+2]));*/
+    result = BsonAppend(interp, bPtr, objv[i], objv[i+1], objv[i+2]);
     if (result != TCL_OK) {
       break;
     }
@@ -678,7 +684,7 @@ NsfMongoClose(Tcl_Interp *UNUSED(interp), mongoc_client_t *connPtr, Tcl_Obj *con
 static int
 NsfMongoConnect(Tcl_Interp *interp, const char *uri)
 {
-  char             channelName[80];
+  char             channelName[POINTER_HANDLE_SIZE];
   mongoc_client_t *clientPtr;
 
   if (uri == NULL) {
@@ -708,12 +714,12 @@ NsfMongoConnect(Tcl_Interp *interp, const char *uri)
    * Make an entry in the symbol table and return entry name it as
    * result.
    */
-  if (Nsf_PointerAdd(interp, channelName, 80u, "mongoc_client_t", clientPtr) != TCL_OK) {
+  if (Nsf_PointerAdd(interp, channelName, sizeof(channelName), "mongoc_client_t", clientPtr) != TCL_OK) {
     mongoc_client_destroy(clientPtr);
     return TCL_ERROR;
   }
 
-  Tcl_SetObjResult(interp, Tcl_NewStringObj(channelName, -1));
+  Tcl_SetObjResult(interp, Tcl_NewStringObj(channelName, TCL_INDEX_NONE));
 
   return TCL_OK;
 }
@@ -805,10 +811,10 @@ NsfCollectionOpen(Tcl_Interp *interp,
 
   collectionPtr = mongoc_client_get_collection(clientPtr, dbName, collectionName);
   if (collectionPtr != NULL) {
-    char buffer[80];
+    char buffer[POINTER_HANDLE_SIZE];
 
-    if (Nsf_PointerAdd(interp, buffer, 80u, "mongoc_collection_t", collectionPtr) == TCL_OK) {
-      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, -1));
+    if (Nsf_PointerAdd(interp, buffer, sizeof(buffer), "mongoc_collection_t", collectionPtr) == TCL_OK) {
+      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, TCL_INDEX_NONE));
       result = TCL_OK;
     } else {
       mongoc_collection_destroy(collectionPtr);
@@ -1028,12 +1034,8 @@ static int NsfMongoCollectionInsert(Tcl_Interp *interp,
   bson_append_oid(bsonPtr, "_id", 3, &oid);
 
   for (i = 0; i < objc; i += 3) {
-    const char *name  = ObjStr(objv[i]);
-    const char *tag   = ObjStr(objv[i+1]);
-    Tcl_Obj    *value = objv[i+2];
-
-    /*fprintf(stderr, "adding pair '%s' (%s) '%s'\n", name, tag, ObjStr(value));*/
-    BsonAppend(interp, bsonPtr, name, tag, value);
+    /*fprintf(stderr, "adding pair '%s' (%s) '%s'\n", ObjStr(name), ObjStr(tag), ObjStr(value));*/
+    BsonAppend(interp, bsonPtr, objv[i], objv[i+1], objv[i+2]);
   }
 
   success = mongoc_collection_insert(collectionPtr, insertFlags, bsonPtr, writeConcern, &bsonError);
@@ -1283,10 +1285,10 @@ NsfMongoCursorAggregate(Tcl_Interp *interp,
                                        pipelinePtr, optionsPtr,
                                        readPrefsPtr);
   if (cursor != NULL) {
-    char buffer[80];
+    char buffer[POINTER_HANDLE_SIZE];
 
-    if (Nsf_PointerAdd(interp, buffer, 80u, "mongoc_cursor_t", cursor) == TCL_OK) {
-      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, -1));
+    if (Nsf_PointerAdd(interp, buffer, sizeof(buffer), "mongoc_cursor_t", cursor) == TCL_OK) {
+      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, TCL_INDEX_NONE));
     } else {
       mongoc_cursor_destroy( cursor );
       result = TCL_ERROR;
@@ -1344,9 +1346,9 @@ NsfMongoCursorFind(Tcl_Interp *interp,
                                              readPrefsPtr);
 
   if (cursor != NULL) {
-    char buffer[80];
-    if (Nsf_PointerAdd(interp, buffer, 80u, "mongoc_cursor_t", cursor) == TCL_OK) {
-      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, -1));
+    char buffer[POINTER_HANDLE_SIZE];
+    if (Nsf_PointerAdd(interp, buffer, sizeof(buffer), "mongoc_cursor_t", cursor) == TCL_OK) {
+      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, TCL_INDEX_NONE));
     } else {
       mongoc_cursor_destroy( cursor );
       result = TCL_ERROR;
@@ -1426,7 +1428,7 @@ static int
 NsfMongoGridFSOpen(Tcl_Interp *interp, mongoc_client_t *clientPtr,
                    const char *dbname, const char *prefix)
 {
-  char             buffer[80];
+  char             buffer[POINTER_HANDLE_SIZE];
   int              result = TCL_OK;
   bson_error_t     bsonError;
   mongoc_gridfs_t *gfsPtr;
@@ -1437,8 +1439,8 @@ NsfMongoGridFSOpen(Tcl_Interp *interp, mongoc_client_t *clientPtr,
     result = NsfPrintError(interp, "mongo::gridfs::open: error: %s", bsonError.message);
   }
 
-  if (Nsf_PointerAdd(interp, buffer, 80u, "mongoc_gridfs_t", gfsPtr) == TCL_OK) {
-    Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, -1));
+  if (Nsf_PointerAdd(interp, buffer, sizeof(buffer), "mongoc_gridfs_t", gfsPtr) == TCL_OK) {
+    Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, TCL_INDEX_NONE));
   } else {
     mongoc_gridfs_destroy(gfsPtr);
     result = TCL_ERROR;
@@ -1468,7 +1470,8 @@ static int
 NsfMongoGridFileCreate(Tcl_Interp *interp,
                        GridfilesourceIdx_t withSource,
                        mongoc_gridfs_t *gridfsPtr,
-                       const char *value, const char *name,
+                       const char *value,
+                       const char *name,
                        const char *contenttype,
                        Tcl_Obj *withMetadata
                        )
@@ -1515,7 +1518,7 @@ NsfMongoGridFileCreate(Tcl_Interp *interp,
       return NsfPrintError(interp, "nsf::gridfile::create: cannot open file '%s' for reading", value);
     }
 
-    for (;; ) {
+    for (;;) {
       ssize_t n = read(fd, iov.iov_base, MONGOC_GRIDFS_READ_CHUNK);
 
       if (n > 0) {
@@ -1646,10 +1649,10 @@ NsfMongoGridFileOpen(Tcl_Interp *interp,
   gridFilePtr = mongoc_gridfs_find_one_with_opts(gridfsPtr, filterPtr, NULL, &bsonError);
 
   if (gridFilePtr != NULL) {
-    char buffer[80];
+    char buffer[POINTER_HANDLE_SIZE];
 
-    if (Nsf_PointerAdd(interp, buffer, 80u, "mongoc_gridfs_file_t", gridFilePtr) == TCL_OK) {
-      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, -1));
+    if (Nsf_PointerAdd(interp, buffer, sizeof(buffer), "mongoc_gridfs_file_t", gridFilePtr) == TCL_OK) {
+      Tcl_SetObjResult(interp, Tcl_NewStringObj(buffer, TCL_INDEX_NONE));
     } else {
       mongoc_gridfs_file_destroy(gridFilePtr);
       result = TCL_ERROR;
@@ -1666,7 +1669,7 @@ NsfMongoGridFileOpen(Tcl_Interp *interp,
 /***********************************************************************
  * GridFile interface
  *
- * Currently offsets and sizes are limited to 32bit integers, we should
+ * Currently offsets and sizes are limited to 32-bit integers, we should
  * relax this later.
  ***********************************************************************/
 
@@ -1708,7 +1711,7 @@ NsfMongoGridFileGetContentlength(Tcl_Interp *interp, mongoc_gridfs_file_t* gridF
 static int
 NsfMongoGridFileGetContentType(Tcl_Interp *interp, mongoc_gridfs_file_t* gridFilePtr)
 {
-  Tcl_SetObjResult(interp, Tcl_NewStringObj(mongoc_gridfs_file_get_content_type(gridFilePtr), -1));
+  Tcl_SetObjResult(interp, Tcl_NewStringObj(mongoc_gridfs_file_get_content_type(gridFilePtr), TCL_INDEX_NONE));
 
   return TCL_OK;
 }
@@ -1882,7 +1885,7 @@ Nsfmongo_Init(Tcl_Interp * interp)
     NsfMongoGlobalObjs = (Tcl_Obj **)ckalloc(sizeof(Tcl_Obj*)*nr_elements(NsfMongoGlobalStrings));
 
     for (i = 0; i < nr_elements(NsfMongoGlobalStrings); i++) {
-      NsfMongoGlobalObjs[i] = Tcl_NewStringObj(NsfMongoGlobalStrings[i], -1);
+      NsfMongoGlobalObjs[i] = Tcl_NewStringObj(NsfMongoGlobalStrings[i], TCL_INDEX_NONE);
       Tcl_IncrRefCount(NsfMongoGlobalObjs[i]);
     }
 
