@@ -1,7 +1,7 @@
 package require nx
 
-package require XOTcl 2.3
-package provide nx::serializer 2.3
+package require XOTcl 2.4
+package provide nx::serializer 2.4.0
 
 # For the time being, we require classical XOTcl.
 
@@ -796,12 +796,15 @@ namespace eval ::nx::serializer {
           } else {
             lappend needed $regObj
           }
+        } else {
+          puts stderr "=== aliasedCmd $aliasedCmd has regObj <$regObj> x '$x' where '$where'"
+          #lappend needed $x
         }
       }
-      # if {[llength $needed]>0} {
-      #  puts stderr "aliases: $x needs $needed"
-      #  puts stderr "set alias-deps for $x - $handle - $needed"
-      # }
+      if {[llength $needed]>0} {
+        puts stderr "aliases: $x needs $needed"
+        puts stderr "set alias-deps for $x - $handle - $needed"
+      }
       set $handle $needed
       return $needed
     }
@@ -875,7 +878,7 @@ namespace eval ::nx::serializer {
       # interpreter when the blueprint script was changed. In the
       # latter case, we have already in the current interpreter
       # predefined objects and classes. When objects are created at
-      # runtime and staying the connection threads, these object will
+      # run time and staying the connection threads, these object will
       # be turned into base class objects, when the classes are
       # deleted and newly defined. Therefore, we cleanup the interp in
       # a first step. Alternate approaches could be to handle these
