@@ -39,7 +39,7 @@
 #
 
 package require nx
-package provide XOTcl 2.3
+package provide XOTcl 2.4.0
 
 #######################################################
 # Classical ::xotcl*
@@ -251,6 +251,7 @@ namespace eval ::xotcl {
   # provide some Tcl-commands as methods for ::xotcl::Object
   ::nsf::method::alias Object append  -frame object ::append
   ::nsf::method::alias Object array   -frame object ::array
+  ::nsf::method::alias Object dict    -frame object ::dict
   ::nsf::method::alias Object eval    -frame object ::eval
   ::nsf::method::alias Object incr    -frame object ::incr
   ::nsf::method::alias Object lappend -frame object ::lappend
@@ -1098,7 +1099,7 @@ namespace eval ::xotcl {
     :property {substdefault}
     :property -accessor public multivalued {
       #
-      # The slot object is an nx object, therefore we need the nx
+      # The slot object is an nx object, therefore, we need the nx
       # "set" variant no matter what xotcl2 uses.
       #
       :public object method value=set {object property value} {
@@ -1466,6 +1467,7 @@ namespace eval ::xotcl {
   # Tcl commands
   set ::nsf::parameter::syntax(::append) "/varName/ ?/value/ ...?"
   set ::nsf::parameter::syntax(::array) "/option/ /arrayName/ ?/arg/ ...?"
+  set ::nsf::parameter::syntax(::dict) "/option/ /dictName|dictValue/ ?/arg/ ...?"
   set ::nsf::parameter::syntax(::eval) "/arg/ ?/arg/ ...?"
   set ::nsf::parameter::syntax(::incr) "/varName/ ?/increment/?"
   set ::nsf::parameter::syntax(::lappend) "/varName/ ?/value/ ...?"
